==> webkitgtk-2.6.5.tar.xz: webkitgtk-2.6.5/Source/WebCore/platform/network/BlobDataFileReference.h <==
/*
 * Copyright (C) 2014 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef BlobDataFileReference_h
#define BlobDataFileReference_h

#include "FileSystem.h"
#include <wtf/RefCounted.h>
#include <wtf/text/WTFString.h>

namespace WebCore {

class BlobDataFileReference : public RefCounted<BlobDataFileReference> {
public:
    static PassRefPtr<BlobDataFileReference> create(const String& path)
    {
        return adoptRef(new BlobDataFileReference(path));
    }

    WEBCORE_EXPORT virtual ~BlobDataFileReference();

    void startTrackingModifications();

    WEBCORE_EXPORT const String& path();
    unsigned long long size();
    double expectedModificationTime();

    virtual void prepareForFileAccess();
    virtual void revokeFileAccess();

protected:
    WEBCORE_EXPORT BlobDataFileReference(const String& path);

private:
#if ENABLE(FILE_REPLACEMENT)
    void generateReplacementFile();
#endif

    String m_path;
#if ENABLE(FILE_REPLACEMENT)
    String m_replacementPath;
    bool m_replacementShouldBeGenerated;
#endif
    unsigned long long m_size;
    double m_expectedModificationTime;
};

}

#endif // BlobDataFileReference_h

==> webkitgtk-2.8.0.tar.xz: webkitgtk-2.8.0/Source/WebCore/platform/network/BlobDataFileReference.h <==
/*
 * Copyright (C) 2014 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef BlobDataFileReference_h
#define BlobDataFileReference_h

#include "FileSystem.h"
#include <wtf/RefCounted.h>
#include <wtf/text/WTFString.h>

namespace WebCore {

class WEBCORE_EXPORT BlobDataFileReference : public RefCounted<BlobDataFileReference> {
public:
    static Ref<BlobDataFileReference> create(const String& path)
    {
        return adoptRef(*new BlobDataFileReference(path));
    }

    WEBCORE_EXPORT virtual ~BlobDataFileReference();

    void startTrackingModifications();

    WEBCORE_EXPORT const String& path();
    unsigned long long size();
    double expectedModificationTime();

    virtual void prepareForFileAccess();
    virtual void revokeFileAccess();

protected:
    WEBCORE_EXPORT BlobDataFileReference(const String& path);

private:
#if ENABLE(FILE_REPLACEMENT)
    void generateReplacementFile();
#endif

    String m_path;
#if ENABLE(FILE_REPLACEMENT)
    String m_replacementPath;
    bool m_replacementShouldBeGenerated;
#endif
    unsigned long long m_size;
    double m_expectedModificationTime;
};

}

#endif // BlobDataFileReference_h
